@@ -9,4 +9,8 @@ pub use signal::shutdown as signal_handling;
 pub use signal::sigpipe;
 pub use verification::program_verification;
 pub use verification::runtime as verification_runtime;
+
+pub use verification::PROGRAM_FUZZING;
 pub use verification::PROGRAM_VERIFICATION;
+pub use verification::SOURCE_RESTORATION;
+pub use verification::UPLOADED_SOURCES_LISTING;
